InputField<T> class abstract

Inheritance
Implementers

Constructors

InputField({Key? key, required String placeholder, String? hintText, ValueChanged<T?>? onChanged, ValueChanged<T?>? onSaved, String? helperText, int minLines = 1, int maxLines = 1, VoidCallback? onSubmit, FormFieldValidator<T>? validator, bool isRequired = true, String? requiredText, T? initialValue, List<TextInputFormatter>? formatters, TextInputType? keyboardType, TextInputAction? inputAction, bool isActive = true, bool isDisabled = false, bool emitDirty = true, bool obscureText = false, bool enableSuggestions = true, bool autocorrect = true, Iterable<String>? autofillHints, Widget? suffix})

Properties

autocorrect bool
final
autofillHints Iterable<String>?
final
emitDirty bool
final
enableSuggestions bool
final
focusNode FocusNode
finalinherited
formatters List<TextInputFormatter>?
getter/setter pair
hasChanges bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
helperText String?
final
hintText String?
final
inputAction TextInputAction?
final
isActive bool
getter/setter pairinherited
isDisabled bool
no setterinherited
isRequired bool
finalinherited
isValid bool
getter/setter pairinherited
key Key?
finalinherited
keyboardType TextInputType?
final
margin EdgeInsets?
finalinherited
maxLines int
final
minLines int
final
obscureText bool
getter/setter pair
onChanged ValueChanged<T?>?
getter/setter pairinherited
onSaved ValueChanged<T?>?
getter/setter pairinherited
onSubmit VoidCallback?
getter/setter pair
placeholder String
final
requiredText String?
Custom required text, by default FormThemeData.requiredText
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix Widget?
no getter
validator FormFieldValidator<T>?
getter/setter pair
value ↔ T?
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) Widget
override
convertFrom(String? value) → T?
On empty string this function should return null
convertTo(T? value) String?
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
disposeWidget() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setDisabled(bool value) → void
inherited
setHasChanged(bool value) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited