IntField class

Inheritance

Constructors

IntField({Key? key, required String placeholder, String? hintText, ValueChanged<int?>? onChanged, ValueChanged<int?>? onSaved, String? helperText, VoidCallback? onSubmit, NumberFieldConstraint<int>? constraint, bool isRequired = true, String? requiredText, int? initialValue, List<TextInputFormatter>? formatters, TextInputType? keyboardType, TextInputAction? inputAction, bool isActive = true, bool isDisabled = false, bool emitDirty = true, bool obscureText = false, bool enableSuggestions = true, bool autocorrect = true, Iterable<String>? autofillHints, Widget? suffix})

Properties

autocorrect bool
finalinherited
autofillHints Iterable<String>?
finalinherited
constraint NumberFieldConstraint<int>?
final
emitDirty bool
finalinherited
enableSuggestions bool
finalinherited
focusNode FocusNode
finalinherited
formatters List<TextInputFormatter>?
getter/setter pairinherited
hasChanges bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
helperText String?
finalinherited
hintText String?
finalinherited
inputAction TextInputAction?
finalinherited
isActive bool
getter/setter pairinherited
isDisabled bool
no setterinherited
isRequired bool
finalinherited
isValid bool
getter/setter pairinherited
key Key?
finalinherited
keyboardType TextInputType?
finalinherited
margin EdgeInsets?
finalinherited
maxLines int
finalinherited
minLines int
finalinherited
obscureText bool
getter/setter pairinherited
onChanged ValueChanged<int?>?
getter/setter pairinherited
onSaved ValueChanged<int?>?
getter/setter pairinherited
onSubmit VoidCallback?
getter/setter pairinherited
placeholder String
finalinherited
requiredText String?
Custom required text, by default FormThemeData.requiredText
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix Widget?
no getterinherited
validator FormFieldValidator<int>?
getter/setter pairinherited
value int?
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
build(BuildContext context) Widget
inherited
convertFrom(String? value) int?
On empty string this function should return null
override
convertTo(int? value) String?
override
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
disposeWidget() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setDisabled(bool value) → void
inherited
setHasChanged(bool value) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited